use nxui::messagebox::MessageBox;
use nxui::natives_and_messaging::{BUTTONSTYLE_YESNO, DIALOGSTYLE_INFORMATION};
use nxui::window::Frame;

fn main() {
    nxui::initialize();
    MessageBox::new("Hello NXUI!","This is a test",DIALOGSTYLE_INFORMATION,BUTTONSTYLE_YESNO).show(Frame::default());
}